You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@trafodion.apache.org by se...@apache.org on 2017/07/21 05:03:52 UTC

[1/5] incubator-trafodion git commit: [TRAFODION-2689] Fixed log file creation of WDG and PSD processes by fixing process creation logic to set TRAF_CONF and TRAF_VAR environment variables in child processes in addition to TRAF_HOME. Updated log4cxx conf

Repository: incubator-trafodion
Updated Branches:
  refs/heads/master 880b20d89 -> e7dedc822


[TRAFODION-2689] Fixed log file creation of WDG and PSD processes by
fixing process creation logic to set TRAF_CONF and TRAF_VAR environment
variables in child processes in addition to TRAF_HOME.
Updated log4cxx configuration settings and removed obsolete
configuration files.
Changed logfile names by removing timestamp and pid from name. The only
exception is the use monitor pid in the file names when in virtual cluster
environment.


Project: http://git-wip-us.apache.org/repos/asf/incubator-trafodion/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-trafodion/commit/869af232
Tree: http://git-wip-us.apache.org/repos/asf/incubator-trafodion/tree/869af232
Diff: http://git-wip-us.apache.org/repos/asf/incubator-trafodion/diff/869af232

Branch: refs/heads/master
Commit: 869af232aa526123a3e5f644b2bcca87d79ceac9
Parents: a3e19b4
Author: Zalo Correa <za...@esgyn.com>
Authored: Mon Jul 17 17:42:02 2017 -0700
Committer: Zalo Correa <za...@esgyn.com>
Committed: Mon Jul 17 17:42:02 2017 -0700

----------------------------------------------------------------------
 core/sqf/conf/log4cxx.monitor.mon.config      |  7 +--
 core/sqf/conf/log4cxx.monitor.mon.snmp.config | 50 ----------------------
 core/sqf/conf/log4cxx.monitor.psd.config      |  2 +-
 core/sqf/conf/log4cxx.monitor.wdg.config      |  2 +-
 core/sqf/conf/log4cxx.monitor.wdg.snmp.config | 48 ---------------------
 core/sqf/monitor/linux/monitor.cxx            | 18 ++++----
 core/sqf/monitor/linux/monlogging.cxx         | 25 +++++------
 core/sqf/monitor/linux/process.cxx            | 20 +++++++--
 core/sqf/monitor/linux/process.h              |  4 +-
 core/sqf/monitor/linux/pstartd.cxx            |  8 ++++
 core/sqf/monitor/linux/watchdog.cxx           | 22 +++++++++-
 core/sqf/monitor/linux/zootest.cxx            |  1 +
 12 files changed, 78 insertions(+), 129 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/869af232/core/sqf/conf/log4cxx.monitor.mon.config
----------------------------------------------------------------------
diff --git a/core/sqf/conf/log4cxx.monitor.mon.config b/core/sqf/conf/log4cxx.monitor.mon.config
index 0ad8d90..9fdb125 100644
--- a/core/sqf/conf/log4cxx.monitor.mon.config
+++ b/core/sqf/conf/log4cxx.monitor.mon.config
@@ -25,13 +25,14 @@
 trafodion.log.dir=${TRAF_HOME}/logs
 trafodion.log.filename.suffix=${TRAFODION_LOG_FILENAME_SUFFIX}
 
-# Logging Threshold
-log4j.threshhold=ALL
-
 # Define the root logger to the system property "trafodion.root.logger".
 trafodion.root.logger=INFO, monAppender
 log4j.rootLogger=${trafodion.root.logger}
 
+# Logging Threshold
+log4j.threshhold=ALL
+
+#
 # Rolling File Appender
 #
 log4j.appender.monAppender=org.apache.log4j.RollingFileAppender

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/869af232/core/sqf/conf/log4cxx.monitor.mon.snmp.config
----------------------------------------------------------------------
diff --git a/core/sqf/conf/log4cxx.monitor.mon.snmp.config b/core/sqf/conf/log4cxx.monitor.mon.snmp.config
deleted file mode 100644
index 6f5e57c..0000000
--- a/core/sqf/conf/log4cxx.monitor.mon.snmp.config
+++ /dev/null
@@ -1,50 +0,0 @@
-#
-# @@@ START COPYRIGHT @@@
-#
-# Licensed to the Apache Software Foundation (ASF) under one
-# or more contributor license agreements.  See the NOTICE file
-# distributed with this work for additional information
-# regarding copyright ownership.  The ASF licenses this file
-# to you under the Apache License, Version 2.0 (the
-# "License"); you may not use this file except in compliance
-# with the License.  You may obtain a copy of the License at
-#
-#   http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing,
-# software distributed under the License is distributed on an
-# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
-# KIND, either express or implied.  See the License for the
-# specific language governing permissions and limitations
-# under the License.
-#
-# @@@ END COPYRIGHT @@@
-#
-
-# Define some default values that can be overridden by system properties
-trafodion.log.dir=${TRAF_HOME}/logs
-trafodion.log.filename.suffix=${TRAFODION_LOG_FILENAME_SUFFIX}
-
-
-# Logging Threshold
-log4j.threshhold=ALL
-
-# Define the root logger to the system property "trafodion.root.logger".
-trafodion.root.logger=INFO, monSnmpAppender
-log4j.rootLogger=${trafodion.root.logger}
-#
-# Rolling File Appender
-#
-log4j.appender.monSnmpAppender=org.apache.log4j.RollingFileAppender
-log4j.appender.monSnmpAppender.file=${trafodion.log.dir}/mon.snmp${trafodion.log.filename.suffix}
-log4j.appender.monSnmpAppender.maxFileSize=100000000
-log4j.appender.monSnmpAppender.maxBackupIndex=1
-log4j.appender.monSnmpAppender.addPid=false
-log4j.appender.monSnmpAppender.layout=org.apache.log4j.PatternLayout
-log4j.appender.monSnmpAppender.layout.ConversionPattern=%d, %p, %c, %m
-log4j.appender.monSnmpAppender.Append=true
-
-log4j.additivity.monSnmpAppender=false 
-
-# Foundation Monitor
-log4j.logger.MON-SNMP=INFO

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/869af232/core/sqf/conf/log4cxx.monitor.psd.config
----------------------------------------------------------------------
diff --git a/core/sqf/conf/log4cxx.monitor.psd.config b/core/sqf/conf/log4cxx.monitor.psd.config
index 0949b26..6b270d8 100644
--- a/core/sqf/conf/log4cxx.monitor.psd.config
+++ b/core/sqf/conf/log4cxx.monitor.psd.config
@@ -33,7 +33,7 @@ log4j.rootLogger=${trafodion.root.logger}
 log4j.threshhold=ALL
 
 #
-# Daily Rolling File Appender
+# Rolling File Appender
 #
 log4j.appender.psdAppender=org.apache.log4j.RollingFileAppender
 log4j.appender.psdAppender.file=${trafodion.log.dir}/pstartd${trafodion.log.filename.suffix}

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/869af232/core/sqf/conf/log4cxx.monitor.wdg.config
----------------------------------------------------------------------
diff --git a/core/sqf/conf/log4cxx.monitor.wdg.config b/core/sqf/conf/log4cxx.monitor.wdg.config
index 79a86e9..6a7d218 100644
--- a/core/sqf/conf/log4cxx.monitor.wdg.config
+++ b/core/sqf/conf/log4cxx.monitor.wdg.config
@@ -32,7 +32,7 @@ log4j.rootLogger=${trafodion.root.logger}
 # Logging Threshold
 log4j.threshhold=ALL
 
-
+#
 # Rolling File Appender
 #
 log4j.appender.wdtAppender=org.apache.log4j.RollingFileAppender

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/869af232/core/sqf/conf/log4cxx.monitor.wdg.snmp.config
----------------------------------------------------------------------
diff --git a/core/sqf/conf/log4cxx.monitor.wdg.snmp.config b/core/sqf/conf/log4cxx.monitor.wdg.snmp.config
deleted file mode 100644
index f4840f5..0000000
--- a/core/sqf/conf/log4cxx.monitor.wdg.snmp.config
+++ /dev/null
@@ -1,48 +0,0 @@
-#
-# @@@ START COPYRIGHT @@@
-#
-# Licensed to the Apache Software Foundation (ASF) under one
-# or more contributor license agreements.  See the NOTICE file
-# distributed with this work for additional information
-# regarding copyright ownership.  The ASF licenses this file
-# to you under the Apache License, Version 2.0 (the
-# "License"); you may not use this file except in compliance
-# with the License.  You may obtain a copy of the License at
-#
-#   http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing,
-# software distributed under the License is distributed on an
-# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
-# KIND, either express or implied.  See the License for the
-# specific language governing permissions and limitations
-# under the License.
-#
-# @@@ END COPYRIGHT @@@
-#
-
-# Define some default values that can be overridden by system properties
-trafodion.log.dir=${TRAF_HOME}/logs
-trafodion.log.filename.suffix=${TRAFODION_LOG_FILENAME_SUFFIX}
-
-# Logging Threshold
-log4j.threshhold=ALL
-
-# Define the root logger to the system property "trafodion.root.logger".
-trafodion.root.logger=INFO, wdtSnmpAppender
-log4j.rootLogger=${trafodion.root.logger}
-#
-# Daily Rolling File Appender
-#
-log4j.appender.wdtSnmpAppender=org.apache.log4j.RollingFileAppender
-log4j.appender.wdtSnmpAppender.file=${trafodion.log.dir}/wdg.snmp${trafodion.log.filename.suffix}
-log4j.appender.wdtSnmpAppender.layout=org.apache.log4j.PatternLayout
-log4j.appender.wdtSnmpAppender.maxFileSize=100000000
-log4j.appender.wdtSnmpAppender.maxBackupIndex=1
-log4j.appender.wdtSnmpAppender.addPid=false
-log4j.appender.wdtSnmpAppender.layout.ConversionPattern=%d, %p, %c, %m
-log4j.appender.wdtSnmpAppender.Append=true
-log4j.additivity.wdtSnmpAppender=false
-
-# Foundation Monitor: SQWatchdog process
-log4j.logger.WDG-SNMP=INFO

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/869af232/core/sqf/monitor/linux/monitor.cxx
----------------------------------------------------------------------
diff --git a/core/sqf/monitor/linux/monitor.cxx b/core/sqf/monitor/linux/monitor.cxx
index d159b11..d89f4c2 100755
--- a/core/sqf/monitor/linux/monitor.cxx
+++ b/core/sqf/monitor/linux/monitor.cxx
@@ -961,6 +961,15 @@ int main (int argc, char *argv[])
 
     const char method_name[] = "main";
 
+    // Set flag to indicate whether we are operating in a real cluster
+    // or a virtual cluster.   This is used throughout the monitor when
+    // behavior differs for a real vs. virtual cluster environment.
+    if ( getenv("SQ_VIRTUAL_NODES") )
+    {
+        IsRealCluster = false;
+        Emulate_Down = true;
+    }
+
     MonLog = new CMonLog( "log4cxx.monitor.mon.config", "MON", "alt.mon", -1, -1, getpid(), "$MONITOR" );
 
     MonLog->setupInMemoryLog();
@@ -973,15 +982,6 @@ int main (int argc, char *argv[])
     util_dmalloc_start();
 #endif
 
-    // Set flag to indicate whether we are operating in a real cluster
-    // or a virtual cluster.   This is used throughout the monitor when
-    // behavior differs for a real vs. virtual cluster environment.
-    if ( getenv("SQ_VIRTUAL_NODES") )
-    {
-        IsRealCluster = false;
-        Emulate_Down = true;
-    }
-
     // Save our execution path
     env = getenv("PWD");
     if ( env )

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/869af232/core/sqf/monitor/linux/monlogging.cxx
----------------------------------------------------------------------
diff --git a/core/sqf/monitor/linux/monlogging.cxx b/core/sqf/monitor/linux/monlogging.cxx
index d5a63f9..725a408 100755
--- a/core/sqf/monitor/linux/monlogging.cxx
+++ b/core/sqf/monitor/linux/monlogging.cxx
@@ -45,6 +45,7 @@ using namespace std;
 
 #define gettid() syscall(__NR_gettid)
 
+extern bool IsRealCluster;
 extern int MyPNID;
 extern CMonLog *MonLog;
 
@@ -121,31 +122,31 @@ CMonLog::CMonLog( const char *log4cxxConfig
     // Log4cxx logging
     char   hostname[MAX_PROCESSOR_NAME] = {'\0'};
     gethostname(hostname, MAX_PROCESSOR_NAME);
-
     char   logFileSuffix[MAX_FILE_NAME];
+
     if (myNid_ != -1)
     {
-        sprintf( logFileSuffix, ".%s.%s.%d.%d.log"
-               , (char *)&startTimeFmt_
+        sprintf( logFileSuffix, ".%s.%d.log"
                , hostname
-               , myNid_
-               , myPid_);
+               , myNid_);
     }
     else if (myPNid_ != -1)
     {
-        sprintf( logFileSuffix, ".%s.%s.%d.%d.log"
-               , (char *)&startTimeFmt_
+        sprintf( logFileSuffix, ".%s.%d.log"
                , hostname
-               , myPNid_
-               , myPid_);
+               , myPNid_);
     }
-    else
+    else if ( myPNid_ == -1 && !IsRealCluster)
     {
-        sprintf( logFileSuffix, ".%s.%s.%d.log"
-               , (char *)&startTimeFmt_
+        sprintf( logFileSuffix, ".%s.%d.log"
                , hostname
                , myPid_);
     }
+    else
+    {
+        sprintf( logFileSuffix, ".%s.log"
+               , hostname );
+    }
 
     CommonLogger::instance().initLog4cxx(log4cxxConfig_.c_str(), logFileSuffix);
 }

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/869af232/core/sqf/monitor/linux/process.cxx
----------------------------------------------------------------------
diff --git a/core/sqf/monitor/linux/process.cxx b/core/sqf/monitor/linux/process.cxx
index a2eef47..8a35c4d 100644
--- a/core/sqf/monitor/linux/process.cxx
+++ b/core/sqf/monitor/linux/process.cxx
@@ -160,7 +160,9 @@ CProcess::CProcess (CProcess * parent, int nid, int pid, PROCESSTYPE type,
     , ldpathStrId_(ldpathStrId)
     , firstInstance_(true)
     , cmpOrEsp_(false)
-    , sqRoot_()
+    , trafConf_()
+    , trafHome_()
+    , trafVar_()
     , fd_stdin_(-1)
     , fd_stdout_(-1)
     , fd_stderr_(-1)
@@ -1469,10 +1471,20 @@ bool CProcess::Create (CProcess *parent, int & result)
     if (env && isdigit(*env))
        numProcessThreads = atoi(env);
 
+    env = getenv( "TRAF_CONF" );
+    if (env)
+    {
+        trafConf_ = env ;
+    }
     env = getenv( "TRAF_HOME" );
     if (env)
     {
-        sqRoot_ = env ;
+        trafHome_ = env ;
+    }
+    env = getenv( "TRAF_VAR" );
+    if (env)
+    {
+        trafVar_ = env ;
     }
 
     // setup default environment variables from monitor or last CreateProcess call
@@ -1540,7 +1552,9 @@ bool CProcess::Create (CProcess *parent, int & result)
         setEnvStrVal ( childEnv, nextEnv, "MPI_INSTR", filename );
     }
 
-    setEnvStrVal ( childEnv, nextEnv, "TRAF_HOME", sqRoot_.c_str() );
+    setEnvStrVal ( childEnv, nextEnv, "TRAF_CONF", trafConf_.c_str() );
+    setEnvStrVal ( childEnv, nextEnv, "TRAF_HOME", trafHome_.c_str() );
+    setEnvStrVal ( childEnv, nextEnv, "TRAF_VAR", trafVar_.c_str() );
     setEnvStrVal ( childEnv, nextEnv, "USER", user );
     setEnvStrVal ( childEnv, nextEnv, "HOME", home );
     setEnvStrVal ( childEnv, nextEnv, "TERM", term );

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/869af232/core/sqf/monitor/linux/process.h
----------------------------------------------------------------------
diff --git a/core/sqf/monitor/linux/pstartd.cxx b/core/sqf/monitor/linux/pstartd.cxx
index f57b550..8d5f588 100644
--- a/core/sqf/monitor/linux/pstartd.cxx
+++ b/core/sqf/monitor/linux/pstartd.cxx
@@ -42,6 +42,7 @@ const char *MyName;
 char ga_ms_su_c_port[MPI_MAX_PORT_NAME] = {0}; // connection port - not used
 
 long trace_settings = 0;
+bool IsRealCluster = true;
 int MyPNID = -1;
 int MyZid = -1;
 int MyNid = -1;
@@ -1238,6 +1239,13 @@ int main (int argc, char *argv[])
     MyNid = monUtil.getNid();
     MyPid = monUtil.getPid();
 
+    // Set flag to indicate whether we are operating in a real cluster
+    // or a virtual cluster.
+    if ( getenv("SQ_VIRTUAL_NODES") )
+    {
+        IsRealCluster = false;
+    }
+
     MonLog = new CMonLog( "log4cxx.monitor.psd.config", "PSD", "alt.pstartd", MyPNID, MyNid, MyPid, MyName );
 
     pStartD = new CPStartD;

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/869af232/core/sqf/monitor/linux/watchdog.cxx
----------------------------------------------------------------------
diff --git a/core/sqf/monitor/linux/watchdog.cxx b/core/sqf/monitor/linux/watchdog.cxx
index 76c92ac..d0eabb8 100644
--- a/core/sqf/monitor/linux/watchdog.cxx
+++ b/core/sqf/monitor/linux/watchdog.cxx
@@ -51,6 +51,7 @@ bool traceOpen = false;
 char traceFileName[MAX_PROCESS_PATH];
 FILE *locio_trace_file = NULL;
 
+bool IsRealCluster = true;
 char MyPort[MPI_MAX_PORT_NAME] = {0};;
 char *MyName;
 char *dbgLine;
@@ -379,7 +380,19 @@ void process_startup(int argc, char *argv[])
     }
     else
     {
-        gp_local_mon_io->acquire_msg( &msg );
+        bool lv_done = false;
+        while ( ! lv_done )
+        {
+            gp_local_mon_io->acquire_msg( &msg );
+            if ( msg )
+            {
+                lv_done = true;
+            }
+            else
+            {
+                sleep( 5 );
+            }
+        }
 
         msg->type = MsgType_Service;
         msg->noreply = true;
@@ -753,6 +766,13 @@ int main (int argc, char *argv[])
     MyPid = atoi (argv[4]);
     gv_ms_su_verif  = MyVerifier = atoi(argv[9]);
 
+    // Set flag to indicate whether we are operating in a real cluster
+    // or a virtual cluster.
+    if ( getenv("SQ_VIRTUAL_NODES") )
+    {
+        IsRealCluster = false;
+    }
+
     MonLog = new CMonLog( "log4cxx.monitor.wdg.config", "WDG", "alt.wdg", MyPNID, MyNid, MyPid, MyName  );
 
     Watchdog = new CWatchdog();

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/869af232/core/sqf/monitor/linux/zootest.cxx
----------------------------------------------------------------------
diff --git a/core/sqf/monitor/linux/zootest.cxx b/core/sqf/monitor/linux/zootest.cxx
index 67ab345..8f08d5a 100644
--- a/core/sqf/monitor/linux/zootest.cxx
+++ b/core/sqf/monitor/linux/zootest.cxx
@@ -44,6 +44,7 @@ using namespace std;
 
 bool debugFlag = true;
 
+bool IsRealCluster = true;
 bool ZClientEnabled = true;
 char Node_name[MAX_PROCESSOR_NAME] = {'\0'};
 char MyPNidStr[8];


[3/5] incubator-trafodion git commit: Fix merge conflict.

Posted by se...@apache.org.
Fix merge conflict.


Project: http://git-wip-us.apache.org/repos/asf/incubator-trafodion/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-trafodion/commit/7ee21d3b
Tree: http://git-wip-us.apache.org/repos/asf/incubator-trafodion/tree/7ee21d3b
Diff: http://git-wip-us.apache.org/repos/asf/incubator-trafodion/diff/7ee21d3b

Branch: refs/heads/master
Commit: 7ee21d3b704d76e5cf42e6a93d02fed44cda7db0
Parents: 90b33b9
Author: Zalo Correa <za...@esgyn.com>
Authored: Mon Jul 17 20:13:06 2017 -0700
Committer: Zalo Correa <za...@esgyn.com>
Committed: Mon Jul 17 20:13:06 2017 -0700

----------------------------------------------------------------------
 core/sqf/conf/log4cxx.monitor.mon.config | 1 -
 1 file changed, 1 deletion(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/7ee21d3b/core/sqf/conf/log4cxx.monitor.mon.config
----------------------------------------------------------------------
diff --git a/core/sqf/conf/log4cxx.monitor.mon.config b/core/sqf/conf/log4cxx.monitor.mon.config
index 08901a1..0ad8d90 100644
--- a/core/sqf/conf/log4cxx.monitor.mon.config
+++ b/core/sqf/conf/log4cxx.monitor.mon.config
@@ -32,7 +32,6 @@ log4j.threshhold=ALL
 trafodion.root.logger=INFO, monAppender
 log4j.rootLogger=${trafodion.root.logger}
 
-#
 # Rolling File Appender
 #
 log4j.appender.monAppender=org.apache.log4j.RollingFileAppender


[2/5] incubator-trafodion git commit: Fix merge conflict.

Posted by se...@apache.org.
Fix merge conflict.


Project: http://git-wip-us.apache.org/repos/asf/incubator-trafodion/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-trafodion/commit/90b33b9f
Tree: http://git-wip-us.apache.org/repos/asf/incubator-trafodion/tree/90b33b9f
Diff: http://git-wip-us.apache.org/repos/asf/incubator-trafodion/diff/90b33b9f

Branch: refs/heads/master
Commit: 90b33b9f23173e88ca04a0fa00ac5a104bd10af7
Parents: 869af23
Author: Zalo Correa <za...@esgyn.com>
Authored: Mon Jul 17 20:10:59 2017 -0700
Committer: Zalo Correa <za...@esgyn.com>
Committed: Mon Jul 17 20:10:59 2017 -0700

----------------------------------------------------------------------
 core/sqf/conf/log4cxx.monitor.mon.config | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/90b33b9f/core/sqf/conf/log4cxx.monitor.mon.config
----------------------------------------------------------------------
diff --git a/core/sqf/conf/log4cxx.monitor.mon.config b/core/sqf/conf/log4cxx.monitor.mon.config
index 9fdb125..08901a1 100644
--- a/core/sqf/conf/log4cxx.monitor.mon.config
+++ b/core/sqf/conf/log4cxx.monitor.mon.config
@@ -25,13 +25,13 @@
 trafodion.log.dir=${TRAF_HOME}/logs
 trafodion.log.filename.suffix=${TRAFODION_LOG_FILENAME_SUFFIX}
 
+# Logging Threshold
+log4j.threshhold=ALL
+
 # Define the root logger to the system property "trafodion.root.logger".
 trafodion.root.logger=INFO, monAppender
 log4j.rootLogger=${trafodion.root.logger}
 
-# Logging Threshold
-log4j.threshhold=ALL
-
 #
 # Rolling File Appender
 #


[5/5] incubator-trafodion git commit: Merge PR 1185 [TRAFODION-2689] Fixed log file creation of WDG and PSD processes

Posted by se...@apache.org.
Merge PR 1185 [TRAFODION-2689] Fixed log file creation of WDG and PSD processes 


Project: http://git-wip-us.apache.org/repos/asf/incubator-trafodion/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-trafodion/commit/e7dedc82
Tree: http://git-wip-us.apache.org/repos/asf/incubator-trafodion/tree/e7dedc82
Diff: http://git-wip-us.apache.org/repos/asf/incubator-trafodion/diff/e7dedc82

Branch: refs/heads/master
Commit: e7dedc8228b1e988392694ac2ad0df997cd19602
Parents: 880b20d 073c81b
Author: selvaganesang <se...@apache.org>
Authored: Fri Jul 21 05:03:28 2017 +0000
Committer: selvaganesang <se...@apache.org>
Committed: Fri Jul 21 05:03:28 2017 +0000

----------------------------------------------------------------------
 core/sqf/conf/log4cxx.monitor.mon.snmp.config | 50 ----------------------
 core/sqf/conf/log4cxx.monitor.psd.config      |  9 ++--
 core/sqf/conf/log4cxx.monitor.wdg.config      |  9 ++--
 core/sqf/conf/log4cxx.monitor.wdg.snmp.config | 48 ---------------------
 core/sqf/monitor/linux/monitor.cxx            | 18 ++++----
 core/sqf/monitor/linux/monlogging.cxx         | 25 +++++------
 core/sqf/monitor/linux/process.cxx            | 20 +++++++--
 core/sqf/monitor/linux/process.h              |  4 +-
 core/sqf/monitor/linux/pstartd.cxx            |  8 ++++
 core/sqf/monitor/linux/watchdog.cxx           | 22 +++++++++-
 core/sqf/monitor/linux/zootest.cxx            |  1 +
 11 files changed, 78 insertions(+), 136 deletions(-)
----------------------------------------------------------------------



[4/5] incubator-trafodion git commit: Code review fixes.

Posted by se...@apache.org.
Code review fixes.


Project: http://git-wip-us.apache.org/repos/asf/incubator-trafodion/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-trafodion/commit/073c81b4
Tree: http://git-wip-us.apache.org/repos/asf/incubator-trafodion/tree/073c81b4
Diff: http://git-wip-us.apache.org/repos/asf/incubator-trafodion/diff/073c81b4

Branch: refs/heads/master
Commit: 073c81b461dd9a52ffb2b0f36357f0de4ac7f163
Parents: 7ee21d3
Author: Zalo Correa <za...@esgyn.com>
Authored: Tue Jul 18 12:27:20 2017 -0700
Committer: Zalo Correa <za...@esgyn.com>
Committed: Tue Jul 18 12:27:20 2017 -0700

----------------------------------------------------------------------
 core/sqf/conf/log4cxx.monitor.psd.config | 7 ++-----
 core/sqf/conf/log4cxx.monitor.wdg.config | 7 ++-----
 2 files changed, 4 insertions(+), 10 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/073c81b4/core/sqf/conf/log4cxx.monitor.psd.config
----------------------------------------------------------------------
diff --git a/core/sqf/conf/log4cxx.monitor.psd.config b/core/sqf/conf/log4cxx.monitor.psd.config
index 6b270d8..394a2e3 100644
--- a/core/sqf/conf/log4cxx.monitor.psd.config
+++ b/core/sqf/conf/log4cxx.monitor.psd.config
@@ -25,10 +25,6 @@
 trafodion.log.dir=${TRAF_HOME}/logs
 trafodion.log.filename.suffix=${TRAFODION_LOG_FILENAME_SUFFIX}
 
-# Define the root logger to the system property "trafodion.root.logger".
-trafodion.root.logger=INFO, psdAppender
-log4j.rootLogger=${trafodion.root.logger}
-
 # Logging Threshold
 log4j.threshhold=ALL
 
@@ -42,9 +38,10 @@ log4j.appender.psdAppender.maxBackupIndex=1
 log4j.appender.psdAppender.addPid=false
 log4j.appender.psdAppender.layout=org.apache.log4j.PatternLayout
 log4j.appender.psdAppender.layout.ConversionPattern=%d, %p, %c, %m
+log4j.appender.psdAppender.immediateFlush=true
 log4j.appender.psdAppender.Append=true
 
 log4j.additivity.psdAppender=false 
 
 # Foundation Monitor - Process Startup Daemon
-log4j.logger.PSD=INFO
+log4j.logger.PSD=INFO,psdAppender

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/073c81b4/core/sqf/conf/log4cxx.monitor.wdg.config
----------------------------------------------------------------------
diff --git a/core/sqf/conf/log4cxx.monitor.wdg.config b/core/sqf/conf/log4cxx.monitor.wdg.config
index 6a7d218..40b3af6 100644
--- a/core/sqf/conf/log4cxx.monitor.wdg.config
+++ b/core/sqf/conf/log4cxx.monitor.wdg.config
@@ -25,10 +25,6 @@
 trafodion.log.dir=${TRAF_HOME}/logs
 trafodion.log.filename.suffix=${TRAFODION_LOG_FILENAME_SUFFIX}
 
-# Define the root logger to the system property "trafodion.root.logger".
-trafodion.root.logger=INFO, wdtAppender
-log4j.rootLogger=${trafodion.root.logger}
-
 # Logging Threshold
 log4j.threshhold=ALL
 
@@ -42,9 +38,10 @@ log4j.appender.wdtAppender.maxBackupIndex=1
 log4j.appender.wdtAppender.addPid=false
 log4j.appender.wdtAppender.layout=org.apache.log4j.PatternLayout
 log4j.appender.wdtAppender.layout.ConversionPattern=%d, %p, %c, %m
+log4j.appender.wdtAppender.immediateFlush=true
 log4j.appender.wdtAppender.Append=true
 
 log4j.additivity.wdtAppender=false 
 
 # Foundation Monitor: SQWatchdog process
-log4j.logger.WDG=INFO
+log4j.logger.WDG=INFO,wdtAppender
diff --git a/core/sqf/monitor/linux/process.h b/core/sqf/monitor/linux/process.h
index d6a56bd..254ee88 100644
--- a/core/sqf/monitor/linux/process.h
+++ b/core/sqf/monitor/linux/process.h
@@ -462,7 +462,9 @@ private:
     strId_t      ldpathStrId_;
     bool         firstInstance_; // reset on persistent process re-creation
     bool         cmpOrEsp_;
-    string       sqRoot_;     // TRAF_HOME passed to object file
+    string       trafConf_;     // TRAF_CONF passed to object file
+    string       trafHome_;     // TRAF_HOME passed to object file
+    string       trafVar_;      // TRAF_VAR passed to object file
 
     string       infile_;    // process's stdin
     string       outfile_;   // process's stdout

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/869af232/core/sqf/monitor/linux/pstartd.cxx
----------------------------------------------------------------------